<?php
/*
 * Plugin Name: Total Testimonial Form
 * Description: Adds a new shortcode [testimonial_form] to allow visitors to submit testimonials via the front-end.
 * Version:     1.0
 * Author:      WPExplorer
 * Author URI:  https://www.wpexplorer.com/
 * License:     GPL2
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: total-testimonials-form
 * Domain Path: /languages
*/

/**
 * Main Total_Testimonial_Form Class.
 *
 * @since 1.0
 */
if ( ! class_exists( 'Total_Testimonial_Form' ) ) {

	final class Total_Testimonial_Form {

		/**
		 * Total_Testimonial_Form constructor.
		 *
		 * @since  1.0
		 * @access public
		 * @return void
		 */
		public function __construct() {
			if ( apply_filters( 'ttf_css', true ) ) {
				add_action( 'wp_head', array( $this, 'css' ) );
			}
			add_shortcode( 'testimonial_form', array( $this, 'shortcode' ) );
		}

		/**
		 * Adds some CSS for the form
		 *
		 * @since  1.0
		 * @access public
		 * @return void
		 */
		public function css() {
			$css = '
				.ttf-field { margin: 0 0 15px; }
				.ttf-label { font-weight: 600; margin-bottom: 5px; }
				.ttf-label, .ttf-field { display: block; }
				.ttf-field input { width: 100%; }
				.ttf-success { margin-bottom: 30px; color: #fff; background: #87bf17; padding: 0.75em; text-align: center; border-radius: 4px; }
				#ttf_form input:invalid { box-shadow: none; }
			';
			if ( function_exists( 'wpex_minify_css' ) ) {
				echo '<style>' . wpex_minify_css( $css ) . '</style>';
			} else {
				echo '<style>' . $css . '</style>';
			}
		}

		/**
		 * Register testimonial_form shortcode
		 *
		 * @since  1.0
		 * @access public
		 * @return void
		 */
		public function shortcode( $atts ) {

			$atts = shortcode_atts( array(

				'field_title'     => 'on',
				'field_name'      => 'on',
				'field_company'   => 'on',
				'field_url'       => 'on',
				'field_rating'    => 'on',
				'field_content'   => 'on',

				'label_title'     => __( 'Review Title', 'total-testimonials-form' ),
				'label_name'      => __( 'Your Name', 'total-testimonials-form' ),
				'label_company'   => __( 'Your Company', 'total-testimonials-form' ),
				'label_url'       => __( 'Your Website URL', 'total-testimonials-form' ),
				'label_rating'    => __( 'Rating', 'total-testimonials-form' ),
				'label_content'   => __( 'Review', 'total-testimonials-form' ),

				'rating_max'      => '5',
				'content_rows'    => 4,
				'content_cols'    => 40,

				'submit'          => __( 'Submit', 'total-testimonials-form' ),

				'success_message' => __( 'Your testimonial was submitted successfully.', 'total-testimonials-form' ),

			), $atts );

			extract( $atts );

			$output = '';

				if ( $saved = $this->save_testimonial( $atts ) ) {
					$output .= $saved;
				}

				$output .= '<form method="post" id="ttf_form">';

					// Title
					if ( 'on' == $field_title ) {
						$value = ( ! $saved && isset( $_POST[ 'ttf_title' ] ) ) ? $_POST[ 'ttf_title' ] : '';
						$output .= '<div class="ttf-field">';
							$output .= '<span class="ttf-label"><label for="ttf_title">' . esc_html( $label_title ) . '</label></span>';
							$output .= '<span class="ttf-input"><input type="text" name="ttf_title" id="ttf_title" value="' . wp_strip_all_tags( $value ) . '" required></span>';
						$output .= '</div>';
					}

					// Name
					if ( 'on' == $field_name ) {
						$value = ( ! $saved && isset( $_POST[ 'ttf_name' ] ) ) ? $_POST[ 'ttf_name' ] : '';
						$output .= '<div class="ttf-field">';
							$output .= '<span class="ttf-label"><label for="ttf_name">' . esc_html( $label_name ) . '</label></span>';
							$output .= '<span class="ttf-input"><input type="text" name="ttf_name" id="ttf_name" value="' . wp_strip_all_tags( $value ) . '" required></span>';
						$output .= '</div>';
					}

					// Company
					if ( 'on' == $field_company ) {
						$value = ( ! $saved && isset( $_POST[ 'ttf_company' ] ) ) ? $_POST[ 'ttf_company' ] : '';
						$output .= '<div class="ttf-field">';
							$output .= '<span class="ttf-label"><label for="ttf_company">' . esc_html( $label_company ) . '</label></span>';
							$output .= '<span class="ttf-input"><input type="text" name="ttf_company" value="' . wp_strip_all_tags( $value ) . '" id="ttf_company"></span>';
						$output .= '</div>';
					}

					// URL
					if ( 'on' == $field_url ) {
						$value = ( ! $saved && isset( $_POST[ 'ttf_url' ] ) ) ? $_POST[ 'ttf_url' ] : '';
						$output .= '<div class="ttf-field">';
							$output .= '<span class="ttf-label"><label for="ttf_url">' . esc_html( $label_url ) . '</label></span>';
							$output .= '<span class="ttf-input"><input type="text" name="ttf_url" id="ttf_url" value="' . wp_strip_all_tags( $value ) . '"></span>';
						$output .= '</div>';
					}

					// Rating
					if ( 'on' == $field_rating ) {
						$value = ( ! $saved && isset( $_POST[ 'ttf_rating' ] ) ) ? $_POST[ 'ttf_rating' ] : '';
						$output .= '<div class="ttf-field">';
							$output .= '<span class="ttf-label"><label for="ttf_rating">' . esc_html( $label_rating ) . '</label></span>';
							$output .= '<div class="ttf-select wpex-select-wrap"><select name="ttf_rating" id="ttf_rating">';
								$x = absint( $rating_max );
								while ( $x > 0 ) {
									$output .= '<option value="' . $x .'" ' . selected( $value, $x, false ) . '>' . $x .'</option>';
									$x--;
								}
							$output .= '</select></div>';
						$output .= '</div>';
					}

					// Review
					if ( 'on' == $field_content ) {
						$value = ( ! $saved && isset( $_POST[ 'ttf_content' ] ) ) ? $_POST[ 'ttf_content' ] : '';
						$required = apply_filters( 'ttf_post_content_required', true ) ? ' required' : '';
						$output .= '<div class="ttf-field">';
							$output .= '<span class="ttf-label"><label for="ttf_content">' . esc_html( $label_content ) . '</label></span>';
							$output .= '<span class="ttf-textarea"><textarea type="text" name="ttf_content" id="ttf_content" rows="' . absint( $content_rows ) . '" cols="' . absint( $content_cols ) . '"' . $required . '>' . wp_strip_all_tags( $value ) . '</textarea></span>';
						$output .= '</div>';
					}

					$output .= wp_nonce_field( 'ttf_nonce_action', 'ttf_nonce_field', true, false );

					$output .= '<input type="submit" class="ttf-submit" value="' . esc_attr( $submit ) . '">';

				$output .= '</form>';

			return $output;

		}

		/**
		 * Save testmionial based on submission
		 *
		 * @since  1.0
		 * @access public
		 * @return void
		 */
		public function save_testimonial( $atts ) {

			// IMPORTANT SECURITY CHECK
			if ( empty( $_POST[ 'ttf_nonce_field' ] ) || ! wp_verify_nonce( $_POST[ 'ttf_nonce_field' ], 'ttf_nonce_action' ) ) {
				return;
			}

			if ( apply_filters( 'ttf_post_content_required', true ) && empty( $_POST[ 'ttf_content' ] ) ) {
				return;
			}

			$args = array(
				'post_title'   => isset( $_POST[ 'ttf_title' ] ) ? trim( wp_strip_all_tags( $_POST[ 'ttf_title' ] ) ) : __( 'New Testimonial', 'total-testimonials-form' ),
				'post_content' => wp_strip_all_tags( $_POST[ 'ttf_content' ] ),
				'post_status'  => apply_filters( 'ttf_new_status', 'pending' ),
				'post_type'    => 'testimonials',
			);

			$meta_input = array();

			if ( isset( $_POST[ 'ttf_name' ] ) ) {
				$meta_input[ 'wpex_testimonial_author' ] = trim( wp_strip_all_tags( $_POST[ 'ttf_name' ] ) );
			}

			if ( isset( $_POST[ 'ttf_company' ] ) ) {
				$meta_input[ 'wpex_testimonial_company' ] = trim( wp_strip_all_tags( $_POST[ 'ttf_company' ] ) );
			}

			if ( isset( $_POST[ 'ttf_url' ] ) ) {
				$meta_input[ 'wpex_testimonial_url' ] = trim( wp_strip_all_tags( $_POST[ 'ttf_url' ] ) );
			}

			if ( isset( $_POST[ 'ttf_rating' ] ) ) {
				$meta_input[ 'wpex_post_rating' ] = absint( wp_strip_all_tags( $_POST[ 'ttf_rating' ] ) );
			}

			if ( $meta_input ) {
				$args[ 'meta_input' ] = $meta_input;
			}

			$post_id = wp_insert_post( $args );

			if ( ! is_wp_error( $post_id ) ) {
				if ( ! empty( $atts[ 'success_message' ] ) ) {
					return '<div class="ttf-success">' . wp_strip_all_tags( $atts[ 'success_message' ] ) . '</div>';
				}
			} else {
				echo $post_id->get_error_message();
			}

		}

	}

	new Total_Testimonial_Form;

}